////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 2013-2021 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif

#if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
   // This one needs to be global.
#  pragma GCC diagnostic ignored "-Wunused-function"

   // Disable these warnings for code that is generated by flex, including
   // pattern rules.  Push the current state so we can restore the warning
   // state prior to functions we define at the bottom of the file.
#  pragma GCC diagnostic push
#  pragma GCC diagnostic ignored "-Wold-style-cast"
#  pragma GCC diagnostic ignored "-Wsign-compare"
#  pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
#endif

// Define away the deprecated register storage class specifier to avoid
// potential warnings about it.
#if ! defined (register)
#  define register
#endif

#line 50 "libinterp/corefcn/oct-tex-lexer.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define octave_tex__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer octave_tex__create_buffer
#endif

#ifdef yy_delete_buffer
#define octave_tex__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer octave_tex__delete_buffer
#endif

#ifdef yy_scan_buffer
#define octave_tex__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer octave_tex__scan_buffer
#endif

#ifdef yy_scan_string
#define octave_tex__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string octave_tex__scan_string
#endif

#ifdef yy_scan_bytes
#define octave_tex__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes octave_tex__scan_bytes
#endif

#ifdef yy_init_buffer
#define octave_tex__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer octave_tex__init_buffer
#endif

#ifdef yy_flush_buffer
#define octave_tex__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer octave_tex__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define octave_tex__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state octave_tex__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define octave_tex__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer octave_tex__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define octave_tex_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state octave_tex_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define octave_tex_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state octave_tex_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define octave_tex_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack octave_tex_ensure_buffer_stack
#endif

#ifdef yylex
#define octave_tex_lex_ALREADY_DEFINED
#else
#define yylex octave_tex_lex
#endif

#ifdef yyrestart
#define octave_tex_restart_ALREADY_DEFINED
#else
#define yyrestart octave_tex_restart
#endif

#ifdef yylex_init
#define octave_tex_lex_init_ALREADY_DEFINED
#else
#define yylex_init octave_tex_lex_init
#endif

#ifdef yylex_init_extra
#define octave_tex_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra octave_tex_lex_init_extra
#endif

#ifdef yylex_destroy
#define octave_tex_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy octave_tex_lex_destroy
#endif

#ifdef yyget_debug
#define octave_tex_get_debug_ALREADY_DEFINED
#else
#define yyget_debug octave_tex_get_debug
#endif

#ifdef yyset_debug
#define octave_tex_set_debug_ALREADY_DEFINED
#else
#define yyset_debug octave_tex_set_debug
#endif

#ifdef yyget_extra
#define octave_tex_get_extra_ALREADY_DEFINED
#else
#define yyget_extra octave_tex_get_extra
#endif

#ifdef yyset_extra
#define octave_tex_set_extra_ALREADY_DEFINED
#else
#define yyset_extra octave_tex_set_extra
#endif

#ifdef yyget_in
#define octave_tex_get_in_ALREADY_DEFINED
#else
#define yyget_in octave_tex_get_in
#endif

#ifdef yyset_in
#define octave_tex_set_in_ALREADY_DEFINED
#else
#define yyset_in octave_tex_set_in
#endif

#ifdef yyget_out
#define octave_tex_get_out_ALREADY_DEFINED
#else
#define yyget_out octave_tex_get_out
#endif

#ifdef yyset_out
#define octave_tex_set_out_ALREADY_DEFINED
#else
#define yyset_out octave_tex_set_out
#endif

#ifdef yyget_leng
#define octave_tex_get_leng_ALREADY_DEFINED
#else
#define yyget_leng octave_tex_get_leng
#endif

#ifdef yyget_text
#define octave_tex_get_text_ALREADY_DEFINED
#else
#define yyget_text octave_tex_get_text
#endif

#ifdef yyget_lineno
#define octave_tex_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno octave_tex_get_lineno
#endif

#ifdef yyset_lineno
#define octave_tex_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno octave_tex_set_lineno
#endif

#ifdef yyget_column
#define octave_tex_get_column_ALREADY_DEFINED
#else
#define yyget_column octave_tex_get_column
#endif

#ifdef yyset_column
#define octave_tex_set_column_ALREADY_DEFINED
#else
#define yyset_column octave_tex_set_column
#endif

#ifdef yywrap
#define octave_tex_wrap_ALREADY_DEFINED
#else
#define yywrap octave_tex_wrap
#endif

#ifdef yyget_lval
#define octave_tex_get_lval_ALREADY_DEFINED
#else
#define yyget_lval octave_tex_get_lval
#endif

#ifdef yyset_lval
#define octave_tex_set_lval_ALREADY_DEFINED
#else
#define yyset_lval octave_tex_set_lval
#endif

#ifdef yyalloc
#define octave_tex_alloc_ALREADY_DEFINED
#else
#define yyalloc octave_tex_alloc
#endif

#ifdef yyrealloc
#define octave_tex_realloc_ALREADY_DEFINED
#else
#define yyrealloc octave_tex_realloc
#endif

#ifdef yyfree
#define octave_tex_free_ALREADY_DEFINED
#else
#define yyfree octave_tex_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define octave_tex_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 128
#define YY_END_OF_BUFFER 129
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[465] =
    {   0,
        0,    0,    0,    0,    0,    0,  129,  127,  126,  127,
       16,   17,   14,   15,    3,    2,    3,    1,    5,    4,
      123,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   22,   20,   21,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   38,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   18,   19,
        2,    1,    1,    1,    0,    0,   64,    0,    0,    0,
        0,   55,    0,   63,    0,    0,    0,    0,   54,    0,
        0,    0,    0,    0,    6,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,   96,    0,    7,    0,    0,    0,
        0,    0,    0,    0,   35,    0,    0,  100,   36,    0,
        0,    0,    0,    0,    0,    0,   39,   79,    0,    0,
        0,    0,    0,    0,    0,    9,    0,    8,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   62,   37,    0,
        1,    0,    0,    0,    0,    0,   58,   59,    0,    0,
        0,    0,    0,    0,    0,    0,   82,    0,    0,   86,
        0,   47,    0,    0,    0,    0,    0,   87,  125,    0,
        0,   85,    0,    0,    0,   29,    0,    0,    0,    0,
       97,    0,    0,   78,    0,    0,    0,    0,    0,    0,

        0,   93,    0,  101,    0,   73,  121,    0,    0,    0,
        0,    0,    0,   46,    0,    0,   48,    0,    0,    0,
       41,    0,    0,  103,    0,    0,    0,    0,   44,    0,
        0,    0,    0,    0,   88,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       24,    0,   80,   83,    0,    0,  105,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   32,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  107,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   69,    0,    0,    0,    0,    0,

        0,    0,    0,   28,   51,   50,    0,    0,   60,    0,
       56,   52,    0,   61,   23,   70,    0,    0,    0,   13,
        0,   26,    0,    0,    0,  102,    0,    0,    0,    0,
       25,    0,   66,   33,    0,    0,  117,  122,    0,    0,
        0,   68,   49,   90,    0,    0,    0,   67,    0,    0,
      120,    0,    0,   42,    0,    0,    0,   30,   81,    0,
        0,   40,    0,    0,   89,   53,    0,    0,    0,  104,
       84,    0,    0,    0,    0,    0,    0,   72,    0,    0,
       71,    0,   34,  116,    0,    0,  115,   92,   91,    0,
      106,  119,  118,    0,    0,   94,   98,    0,    0,    0,

        0,    0,    0,   57,    0,    0,    0,    0,    0,   27,
        0,    0,    0,    0,    0,   65,    0,    0,    0,    0,
      113,   45,    0,    0,    0,    0,   74,    0,    0,    0,
        0,   10,   11,    0,    0,    0,    0,    0,   95,   99,
       43,   31,  109,    0,    0,  124,    0,  114,   76,  108,
        0,    0,   77,  111,   12,    0,    0,  110,   75,    0,
        0,    0,  112,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    1,    4,    1,    5,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    7,    1,    1,
        8,    1,    9,    1,    1,   10,    1,    1,   11,   12,
        1,   13,   14,   15,   16,    1,    1,   17,    1,    1,
       18,   19,   20,   21,   22,    1,   23,   24,   25,   26,

       27,   28,   29,   30,   31,    1,   32,   33,   34,   35,
       36,   37,   38,   39,   40,   41,   42,   43,   44,   45,
       46,   47,   48,    1,   49,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[50] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[468] =
    {   0,
        0,    4,    0,    6,  434,  433,  480,  483,  483,   49,
      483,  483,  483,  483,  483,  477,    8,   11,  483,  483,
      483,  451,  454,  442,    1,  441,    0,    2,  443,  443,
      435,  440,  483,  483,  483,    1,   72,   79,    8,    5,
      434,   24,  442,   72,  445,   97,   64,  103,   95,  110,
      123,  125,   88,  430,  104,    0,  435,  438,  483,  483,
      462,   98,  111,  155,  430,  428,  483,  427,  432,  432,
      427,  483,  426,  483,  427,  426,  427,  413,  483,   18,
      423,  414,  409,  408,  483,  415,  410,  410,  414,  405,
      401,  131,  405,  109,   44,  397,  400,  397,  415,  406,

      104,  402,  397,  411,  124,  392,  483,  395,  135,  404,
      394,  135,  396,  402,  483,  403,  142,  483,  483,  399,
      392,  391,  392,  383,  382,  389,  483,  483,  141,  388,
      383,  390,  383,  379,  385,  483,  145,  483,  390,  151,
      370,  384,  376,  153,  370,  381,  381,  483,  483,  365,
      176,  364,  370,  379,  361,  372,  483,  483,  370,  365,
      357,  366,  359,  365,  361,  354,  483,  369,  358,  483,
      349,  483,  364,  364,  351,  357,  339,  483,  483,  343,
      349,  483,  347,  350,  349,  483,  339,  337,  354,  342,
      483,  336,  333,  483,  350,  335,  347,  341,  338,  327,

      326,  483,  330,  483,  332,  483,  483,  335,  321,  339,
      327,  319,  322,  483,  324,  320,  483,  327,  324,  318,
      483,  323,  318,  483,  325,  310,  309,  322,  483,  306,
      319,  306,  313,  146,  483,  314,  319,  318,  317,  313,
      315,  314,  295,  312,  311,  300,  302,  308,  303,  293,
      483,  301,  483,  483,  287,  287,  483,  286,  301,  287,
      299,  288,  277,  278,  149,  285,  294,  275,  269,  483,
      291,  287,  279,  278,  270,  155,  273,  285,  284,  266,
      265,  277,  272,  483,  275,  260,  267,  266,  262,  256,
      273,  268,  267,  266,  483,  269,  251,  251,  256,  257,

      256,  256,  258,  483,  483,  483,  261,  244,  483,  259,
      483,  483,  245,  483,  483,  483,  235,  238,  236,  259,
      245,  483,  240,  235,  237,  483,  232,  248,  239,  236,
      483,  228,  483,  483,  244,  239,  483,  483,  226,  233,
      224,  483,  483,  483,  232,  221,  237,  483,  223,  231,
      483,  218,  233,  483,  215,  213,  212,  483,  483,  216,
      215,  483,  221,  222,  483,  483,  209,  208,  211,  483,
      483,  214,  205,  214,  216,  202,  205,  483,  205,  191,
      483,  195,  483,  483,  197,  206,  483,  483,  483,  201,
      483,  483,  483,  194,  190,  204,  203,  185,  193,  193,

      185,  189,  185,  483,  182,  193,  191,  180,  183,  483,
      191,  190,  185,  179,  184,  483,  174,  181,  173,  172,
      483,  483,  186,  185,  163,  170,  483,  181,  163,  161,
      158,  483,  483,  160,  156,  158,  162,  156,  483,  483,
      483,  483,  483,  152,  175,  483,  161,  483,  483,  483,
      168,  141,  483,  483,  483,  114,  108,  483,  483,   89,
       65,   25,  483,  483,   17,    8,    0
    } ;

static const flex_int16_t yy_def[468] =
    {   0,
      465,  465,  466,  466,  467,  467,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,

      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,

      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,

      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,

      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,    0,  464,  464,  464
    } ;

static const flex_int16_t yy_nxt[533] =
    {   0,
       19,   16,    9,   17,   18,   18,    9,   16,   15,   17,
       18,   18,   62,   62,   63,   64,   64,    8,   10,  464,
       11,   12,   10,   68,   11,   12,  147,   69,   74,   71,
       72,  464,   75,   80,   94,   81,  148,   82,   95,   73,
       83,   97,   98,   96,  163,   99,  102,   13,   14,  100,
      103,   13,   14,   21,  164,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   31,   32,  181,   33,  463,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
       45,   46,   47,   48,   49,   50,  182,   51,   52,   53,
       54,   55,   56,   57,  114,   58,   59,   60,   84,   85,

      462,   87,   62,   62,   88,  115,  105,  106,   89,   90,
      141,   91,  107,   86,   92,  151,  151,  142,  143,  109,
       93,  110,  111,  112,  113,  116,  145,  461,  120,  117,
      146,  121,  124,  118,  122,  123,  125,  179,  188,  126,
      127,  180,  189,  128,  119,  131,  460,  132,  129,  130,
      133,  193,  134,  135,  459,  137,  136,  138,   63,   64,
       64,  139,  201,  175,  194,  176,  140,  177,  197,  198,
      206,  215,  202,  223,  226,  232,  216,  339,  224,  207,
      151,  151,  300,  328,  458,  301,  302,  227,  329,  228,
      457,  456,  233,  340,  455,  454,  453,  452,  451,  450,

      449,  448,  447,  446,  445,  444,  443,  442,  441,  440,
      439,  438,  437,  436,  435,  434,  433,  432,  431,  430,
      429,  428,  427,  426,  425,  424,  423,  422,  421,  420,
      419,  418,  417,  416,  415,  414,  413,  412,  411,  410,
      409,  408,  407,  406,  405,  404,  403,  402,  401,  400,
      399,  398,  397,  396,  395,  394,  393,  392,  391,  390,
      389,  388,  387,  386,  385,  384,  383,  382,  381,  380,
      379,  378,  377,  376,  375,  374,  373,  372,  371,  370,
      369,  368,  367,  366,  365,  364,  363,  362,  361,  360,
      359,  358,  357,  356,  355,  354,  353,  352,  351,  350,

      349,  348,  347,  346,  345,  344,  343,  342,  341,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  327,  326,
      325,  324,  323,  322,  321,  320,  319,  318,  317,  316,
      315,  314,  313,  312,  311,  310,  309,  308,  307,  306,
      305,  304,  303,  299,  298,  297,  296,  295,  294,  293,
      292,  291,  290,  289,  288,  287,  286,  285,  284,  283,
      282,  281,  280,  279,  278,  277,  276,  275,  274,  273,
      272,  271,  270,  269,  268,  267,  266,  265,  264,  263,
      262,  261,  260,  259,  258,  257,  256,  255,  254,  253,
      252,  251,  250,  249,  248,  247,  246,  245,  244,  243,

      242,  241,  240,  239,  238,  237,  236,  235,  234,  231,
      230,  229,  225,  222,  221,  220,  219,  218,  217,  214,
      213,  212,  211,  210,  209,  208,  205,  204,  203,  200,
      199,  196,  195,  192,  191,  190,  187,  186,  185,  184,
      183,  178,  174,  173,  172,  171,  170,  169,  168,  167,
      166,  165,  162,  161,  160,  159,  158,  157,  156,  155,
      154,  153,  152,   61,  150,  149,  144,  108,  104,  101,
       79,   78,   77,   76,   70,   67,   66,   65,   61,  464,
       20,   20,    7,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,

      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464
    } ;

static const flex_int16_t yy_chk[533] =
    {   0,
      467,    3,    1,    3,    3,    3,    2,    4,  466,    4,
        4,    4,   17,   17,   18,   18,   18,  465,    1,    0,
        1,    1,    2,   25,    2,    2,   56,   25,   28,   27,
       27,    0,   28,   36,   39,   36,   56,   36,   39,   27,
       36,   40,   40,   39,   80,   40,   42,    1,    1,   40,
       42,    2,    2,   10,   80,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   95,   10,  462,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   95,   10,   10,   10,
       10,   10,   10,   10,   47,   10,   10,   10,   37,   37,

      461,   38,   62,   62,   38,   47,   44,   44,   38,   38,
       53,   38,   44,   37,   38,   63,   63,   53,   53,   46,
       38,   46,   46,   46,   46,   48,   55,  460,   49,   48,
       55,   49,   50,   48,   49,   49,   50,   94,  101,   50,
       50,   94,  101,   50,   48,   51,  457,   51,   50,   50,
       51,  105,   51,   51,  456,   52,   51,   52,   64,   64,
       64,   52,  112,   92,  105,   92,   52,   92,  109,  109,
      117,  129,  112,  137,  140,  144,  129,  276,  137,  117,
      151,  151,  234,  265,  452,  234,  234,  140,  265,  140,
      451,  447,  144,  276,  445,  444,  438,  437,  436,  435,

      434,  431,  430,  429,  428,  426,  425,  424,  423,  420,
      419,  418,  417,  415,  414,  413,  412,  411,  409,  408,
      407,  406,  405,  403,  402,  401,  400,  399,  398,  397,
      396,  395,  394,  390,  386,  385,  382,  380,  379,  377,
      376,  375,  374,  373,  372,  369,  368,  367,  364,  363,
      361,  360,  357,  356,  355,  353,  352,  350,  349,  347,
      346,  345,  341,  340,  339,  336,  335,  332,  330,  329,
      328,  327,  325,  324,  323,  321,  320,  319,  318,  317,
      313,  310,  308,  307,  303,  302,  301,  300,  299,  298,
      297,  296,  294,  293,  292,  291,  290,  289,  288,  287,

      286,  285,  283,  282,  281,  280,  279,  278,  277,  275,
      274,  273,  272,  271,  269,  268,  267,  266,  264,  263,
      262,  261,  260,  259,  258,  256,  255,  252,  250,  249,
      248,  247,  246,  245,  244,  243,  242,  241,  240,  239,
      238,  237,  236,  233,  232,  231,  230,  228,  227,  226,
      225,  223,  222,  220,  219,  218,  216,  215,  213,  212,
      211,  210,  209,  208,  205,  203,  201,  200,  199,  198,
      197,  196,  195,  193,  192,  190,  189,  188,  187,  185,
      184,  183,  181,  180,  177,  176,  175,  174,  173,  171,
      169,  168,  166,  165,  164,  163,  162,  161,  160,  159,

      156,  155,  154,  153,  152,  150,  147,  146,  145,  143,
      142,  141,  139,  135,  134,  133,  132,  131,  130,  126,
      125,  124,  123,  122,  121,  120,  116,  114,  113,  111,
      110,  108,  106,  104,  103,  102,  100,   99,   98,   97,
       96,   93,   91,   90,   89,   88,   87,   86,   84,   83,
       82,   81,   78,   77,   76,   75,   73,   71,   70,   69,
       68,   66,   65,   61,   58,   57,   54,   45,   43,   41,
       32,   31,   30,   29,   26,   24,   23,   22,   16,    7,
        6,    5,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,

      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  464,  464,  464,
      464,  464
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "libinterp/corefcn/oct-tex-lexer.ll"
/* DO NOT EDIT. AUTOMATICALLY GENERATED FROM oct-tex-lexer.in.ll and oct-tex-symbols.in. */



#line 66 "libinterp/corefcn/oct-tex-lexer.ll"

#include "unistd-wrappers.h"

#include "text-engine.h"

// oct-tex-parser.h must be included after text-engine.h
#include "oct-tex-parser.h"

// FIXME: with bison 3.x, OCTAVE_TEX_STYPE appears in the generated
// oct-parse.h file, but there is no definition for YYSTYPE, which is
// needed by the code that is generated by flex.  I can't seem to find
// a way to tell flex to use OCTAVE_TEX_STYPE instead of YYSTYPE in
// the code it generates, or to tell bison to provide the definition
// of YYSTYPE in the generated oct-parse.h file.

#if defined (OCTAVE_TEX_STYPE_IS_DECLARED) && ! defined YYSTYPE
#  define YYSTYPE OCTAVE_TEX_STYPE
#endif

#define YY_NO_UNISTD_H 1
#define isatty octave_isatty_wrapper
#define yyguts_t octave_tex_yyguts_t

#line 988 "libinterp/corefcn/oct-tex-lexer.cc"
#line 989 "libinterp/corefcn/oct-tex-lexer.cc"

#define INITIAL 0
#define NUM_MODE 1
#define MAYBE_NUM_MODE 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 94 "libinterp/corefcn/oct-tex-lexer.ll"



#line 98 "libinterp/corefcn/oct-tex-lexer.ll"
// Numeric values.


#line 1273 "libinterp/corefcn/oct-tex-lexer.cc"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 465 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 483 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 101 "libinterp/corefcn/oct-tex-lexer.ll"
{
    int nread = sscanf (yytext, "%lf", &(yylval->num));

    if (nread == 1)
      return NUM;
  }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 108 "libinterp/corefcn/oct-tex-lexer.ll"
{ }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 110 "libinterp/corefcn/oct-tex-lexer.ll"
{
    yyless (0);
    BEGIN (INITIAL);
  }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 115 "libinterp/corefcn/oct-tex-lexer.ll"
{
    BEGIN (NUM_MODE);
    return START;
  }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 120 "libinterp/corefcn/oct-tex-lexer.ll"
{
    yyless (0);
    BEGIN (INITIAL);
  }
	YY_BREAK

// Simple commands.

case 6:
YY_RULE_SETUP
#line 129 "libinterp/corefcn/oct-tex-lexer.ll"
{ return BF; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 130 "libinterp/corefcn/oct-tex-lexer.ll"
{ return IT; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 131 "libinterp/corefcn/oct-tex-lexer.ll"
{ return SL; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 132 "libinterp/corefcn/oct-tex-lexer.ll"
{ return RM; }
	YY_BREAK

// Generic font commands.

case 10:
YY_RULE_SETUP
#line 138 "libinterp/corefcn/oct-tex-lexer.ll"
{ return FONTNAME; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 140 "libinterp/corefcn/oct-tex-lexer.ll"
{
    BEGIN (MAYBE_NUM_MODE);
    return FONTSIZE;
  }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 145 "libinterp/corefcn/oct-tex-lexer.ll"
{
    BEGIN (MAYBE_NUM_MODE);
    return COLOR_RGB;
  }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 150 "libinterp/corefcn/oct-tex-lexer.ll"
{ return COLOR; }
	YY_BREAK

// Special characters.

case 14:
YY_RULE_SETUP
#line 156 "libinterp/corefcn/oct-tex-lexer.ll"
{ return START; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 157 "libinterp/corefcn/oct-tex-lexer.ll"
{ return END; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 158 "libinterp/corefcn/oct-tex-lexer.ll"
{ return SUPER; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 159 "libinterp/corefcn/oct-tex-lexer.ll"
{ return SUB; }
	YY_BREAK
case 18:
#line 162 "libinterp/corefcn/oct-tex-lexer.ll"
case 19:
#line 163 "libinterp/corefcn/oct-tex-lexer.ll"
case 20:
#line 164 "libinterp/corefcn/oct-tex-lexer.ll"
case 21:
#line 165 "libinterp/corefcn/oct-tex-lexer.ll"
case 22:
YY_RULE_SETUP
#line 165 "libinterp/corefcn/oct-tex-lexer.ll"
{
    yylval->ch = yytext[1];
    return CH;
  }
	YY_BREAK

// Symbols.

case 23:
YY_RULE_SETUP
#line 174 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 0; return SYM; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 175 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 1; return SYM; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 176 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 2; return SYM; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 177 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 3; return SYM; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 178 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 4; return SYM; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 179 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 5; return SYM; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 180 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 6; return SYM; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 181 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 7; return SYM; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 182 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 8; return SYM; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 183 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 9; return SYM; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 184 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 10; return SYM; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 185 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 11; return SYM; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 186 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 12; return SYM; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 187 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 13; return SYM; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 188 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 14; return SYM; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 189 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 15; return SYM; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 190 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 16; return SYM; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 191 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 17; return SYM; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 192 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 18; return SYM; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 193 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 19; return SYM; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 194 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 20; return SYM; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 195 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 21; return SYM; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 196 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 22; return SYM; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 197 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 23; return SYM; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 198 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 24; return SYM; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 199 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 25; return SYM; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 200 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 26; return SYM; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 201 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 27; return SYM; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 202 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 28; return SYM; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 203 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 29; return SYM; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 204 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 30; return SYM; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 205 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 31; return SYM; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 206 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 32; return SYM; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 207 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 33; return SYM; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 208 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 34; return SYM; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 209 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 35; return SYM; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 210 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 36; return SYM; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 211 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 37; return SYM; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 212 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 38; return SYM; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 213 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 39; return SYM; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 214 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 40; return SYM; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 215 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 41; return SYM; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 216 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 42; return SYM; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 217 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 43; return SYM; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 218 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 44; return SYM; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 219 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 45; return SYM; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 220 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 46; return SYM; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 221 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 47; return SYM; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 222 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 48; return SYM; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 223 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 49; return SYM; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 224 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 50; return SYM; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 225 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 51; return SYM; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 226 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 52; return SYM; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 227 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 53; return SYM; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 228 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 54; return SYM; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 229 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 55; return SYM; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 230 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 56; return SYM; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 231 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 57; return SYM; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 232 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 58; return SYM; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 233 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 59; return SYM; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 234 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 60; return SYM; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 235 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 61; return SYM; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 236 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 62; return SYM; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 237 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 63; return SYM; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 238 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 64; return SYM; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 239 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 65; return SYM; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 240 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 66; return SYM; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 241 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 67; return SYM; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 242 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 68; return SYM; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 243 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 69; return SYM; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 244 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 70; return SYM; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 245 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 71; return SYM; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 246 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 72; return SYM; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 247 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 73; return SYM; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 248 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 74; return SYM; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 249 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 75; return SYM; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 250 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 76; return SYM; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 251 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 77; return SYM; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 252 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 78; return SYM; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 253 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 79; return SYM; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 254 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 80; return SYM; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 255 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 81; return SYM; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 256 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 82; return SYM; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 257 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 83; return SYM; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 258 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 84; return SYM; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 259 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 85; return SYM; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 260 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 86; return SYM; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 261 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 87; return SYM; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 262 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 88; return SYM; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 263 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 89; return SYM; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 264 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 90; return SYM; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 265 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 91; return SYM; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 266 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 92; return SYM; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 267 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 93; return SYM; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 268 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 94; return SYM; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 269 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 95; return SYM; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 270 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 96; return SYM; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 271 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 97; return SYM; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 272 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 98; return SYM; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 273 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 99; return SYM; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 274 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 100; return SYM; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 275 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 101; return SYM; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 276 "libinterp/corefcn/oct-tex-lexer.ll"
{ yylval->sym = 102; return SYM; }
	YY_BREAK

// Generic character.

case 126:
/* rule 126 can match eol */
#line 283 "libinterp/corefcn/oct-tex-lexer.ll"
case 127:
/* rule 127 can match eol */
YY_RULE_SETUP
#line 283 "libinterp/corefcn/oct-tex-lexer.ll"
{
    yylval->ch = yytext[0];
    return CH;
  }
	YY_BREAK

#if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
   // Also disable this warning for functions that are generated by flex
   // after the pattern rules.
#  pragma GCC diagnostic ignored "-Wunused-parameter"
#endif

case 128:
YY_RULE_SETUP
#line 296 "libinterp/corefcn/oct-tex-lexer.ll"
ECHO;
	YY_BREAK
#line 2007 "libinterp/corefcn/oct-tex-lexer.cc"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(NUM_MODE):
case YY_STATE_EOF(MAYBE_NUM_MODE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 465 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 465 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 464);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

#define YYTABLES_NAME "yytables"

#line 296 "libinterp/corefcn/oct-tex-lexer.ll"


#if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
   // Restore prevailing warning state for remainder of the file.
#  pragma GCC diagnostic pop
#endif

void *
octave_tex_alloc (yy_size_t size, yyscan_t)
{
  return malloc (size);
}

void *
octave_tex_realloc (void *ptr, yy_size_t size, yyscan_t)
{
return realloc (ptr, size);
}

void
octave_tex_free (void *ptr, yyscan_t)
{
  free (ptr);
}

namespace octave
{
  bool text_parser_tex::init_lexer (const std::string& s)
  {
    if (! scanner)
      octave_tex_lex_init (&scanner);

    if (scanner)
      {
        if (buffer_state)
          {
            octave_tex__delete_buffer (reinterpret_cast<YY_BUFFER_STATE> (buffer_state),
                                       scanner);
            buffer_state = nullptr;
          }

        buffer_state = octave_tex__scan_bytes (s.data (), s.length (), scanner);
      }

    return (scanner && buffer_state);
  }

  void text_parser_tex::destroy_lexer (void)
  {
    if (buffer_state)
      {
        octave_tex__delete_buffer (reinterpret_cast<YY_BUFFER_STATE> (buffer_state),
                                   scanner);
        buffer_state = nullptr;
      }

    if (scanner)
      {
        octave_tex_lex_destroy (scanner);
        scanner = nullptr;
      }
  }
}

